[−][src]Crate rand_split
This crate achieves the functionality of sklearn's train_test_split to generate splits of the data (in this case, a slice), generalized for an arbitrary number of splits (see split_parts).
It also provides some handy wrappers to generate train-test and train-test-validation splits.
Functions
| split_parts | Split the elements of a container in randomized sets which contain a
a part (in |
| train_test_split | Generate train-test splits. Wrapper around |
| ttv_split | Generate train-test-validation splits. Wrapper around |